==> nextcloud-24.0.10.tgz: nextcloud/apps/updatenotification/l10n/ro.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} este disponibil. Află mai multe informații despre cum să faci o actualizare.",
    "Channel updated" : "Canal actualizat",
    "Web updater is disabled" : "Actualizatorul web este dezactivat",
    "Update notifications" : "Notificări de actualizare",
    "The update server could not be reached since %d days to check for new updates." : "Serverul de actualizare nu a mai putut fi contactat de %d zile pentru a verifica dacă există actualizări noi.",
    "Please check the Nextcloud and server log files for errors." : "Vă rugăm să verificați dacă există erori în fișierele jurnal Nextcloud și în fișierele jurnal ale serverului.",
    "Update to %1$s is available." : " Actualizarea la %1$s este disponibilă.",
    "Update for {app} to version %s is available." : "Actualizarea pentru {app} la versiunea %s este disponibilă.",
    "Update notification" : "Notificare de actualizare",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Afișează notificările de actualizare pentru Nextcloud și oferă SSO pentru actualizator.",
    "Update" : "Actualizare",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versiunea pe care o executați nu mai este întreținută. Vă rugăm să vă asigurați că actualizați cât mai curând posibil la o versiune compatibilă.",
    "Apps missing compatible version" : "Aplicații fără versiune compatibilă",
    "View in store" : "Vezi în magazin",
    "Apps with compatible version" : "Aplicații cu versiune compatibilă",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Vă rugăm să rețineți că actualizatorul web nu este recomandat pentru mai mult de 100 de utilizatori! Vă rugăm să folosiți în schimb actualizatorul de linie de comandă!",
    "Open updater" : "Deschide unealta pentru actualizare",
    "Download now" : "Descarcă acum",
    "Please use the command line updater to update." : "Vă rugăm să utilizați programul de actualizare din linia de comandă pentru a efectua actualizarea.",
    "What's new?" : "Ce este nou?",
    "The update check is not yet finished. Please refresh the page." : "Verificarea actualizării nu este încă finalizată. Vă rugăm să reîmprospătați pagina.",
    "Your version is up to date." : "Versiunea curentă este la zi.",
    "Update channel:" : "Canal pentru actualizări:",
    "View changelog" : "Vezi changelog",
    "Beta" : "Beta",
    "Update for %1$s to version %2$s is available." : "Actualizarea pentru %1$s la versiunea %2$s este disponibilă."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-26.0.7p0.tgz: nextcloud/apps/updatenotification/l10n/ro.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} este disponibil. Află mai multe informații despre cum să faci o actualizare.",
    "Channel updated" : "Canal actualizat",
    "Web updater is disabled" : "Actualizatorul web este dezactivat",
    "Update notifications" : "Notificări de actualizare",
    "The update server could not be reached since %d days to check for new updates." : "Serverul de actualizare nu a mai putut fi contactat de %d zile pentru a verifica dacă există actualizări noi.",
    "Please check the Nextcloud and server log files for errors." : "Vă rugăm să verificați dacă există erori în fișierele jurnal Nextcloud și în fișierele jurnal ale serverului.",
    "Update to %1$s is available." : " Actualizarea la %1$s este disponibilă.",
    "Update for {app} to version %s is available." : "Actualizarea pentru {app} la versiunea %s este disponibilă.",
    "Update notification" : "Notificare de actualizare",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Afișează notificările de actualizare pentru Nextcloud și oferă SSO pentru actualizator.",
    "Update" : "Actualizare",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versiunea pe care o executați nu mai este întreținută. Vă rugăm să vă asigurați că actualizați cât mai curând posibil la o versiune compatibilă.",
    "Apps missing compatible version" : "Aplicații fără versiune compatibilă",
    "View in store" : "Vezi în magazin",
    "Apps with compatible version" : "Aplicații cu versiune compatibilă",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Vă rugăm să rețineți că actualizatorul web nu este recomandat pentru mai mult de 100 de utilizatori! Vă rugăm să folosiți în schimb actualizatorul de linie de comandă!",
    "Open updater" : "Deschide unealta pentru actualizare",
    "Download now" : "Descarcă acum",
    "Please use the command line updater to update." : "Vă rugăm să utilizați programul de actualizare din linia de comandă pentru a efectua actualizarea.",
    "What's new?" : "Ce este nou?",
    "View changelog" : "Vezi changelog",
    "The update check is not yet finished. Please refresh the page." : "Verificarea actualizării nu este încă finalizată. Vă rugăm să reîmprospătați pagina.",
    "Your version is up to date." : "Versiunea curentă este la zi.",
    "Beta" : "Beta",
    "Update for %1$s to version %2$s is available." : "Actualizarea pentru %1$s la versiunea %2$s este disponibilă.",
    "Update channel:" : "Canal pentru actualizări:"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
